skretrieval.core.sensor package
===============================

Submodules
----------

skretrieval.core.sensor.pixel module
------------------------------------

.. automodule:: skretrieval.core.sensor.pixel
    :members:
    :undoc-members:
    :show-inheritance:

skretrieval.core.sensor.spectrograph module
-------------------------------------------

.. automodule:: skretrieval.core.sensor.spectrograph
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: skretrieval.core.sensor
    :members:
    :undoc-members:
    :show-inheritance:
